@@ -62,11 +62,9 @@ class Browser extends import_channelOwner.ChannelOwner {
     context._onClose();
     await this._channel.disconnectFromReusedContext({ reason });
   }
-  async _innerNewContext(options = {}, forReuse) {
-    options = this._browserType._playwright.selectors._withSelectorOptions({
-      ...this._browserType._playwright._defaultContextOptions,
-      ...options
-    });
+  async _innerNewContext(userOptions = {}, forReuse) {
+    const options = this._browserType._playwright.selectors._withSelectorOptions(userOptions);
+    await this._instrumentation.runBeforeCreateBrowserContext(options);
     const contextOptions = await (0, import_browserContext.prepareBrowserContextParams)(this._platform, options);
     const response = forReuse ? await this._channel.newContextForReuse(contextOptions) : await this._channel.newContext(contextOptions);
     const context = import_browserContext.BrowserContext.from(response.context);
@@ -120,16 +118,6 @@ class Browser extends import_channelOwner.ChannelOwner {
   async newBrowserCDPSession() {
     return import_cdpSession.CDPSession.from((await this._channel.newBrowserCDPSession()).session);
   }
-  async _launchServer(options = {}) {
-    const serverLauncher = this._browserType._serverLauncher;
-    const browserImpl = this._connection.toImpl?.(this);
-    if (!serverLauncher || !browserImpl)
-      throw new Error("Launching server is not supported");
-    return await serverLauncher.launchServerOnExistingBrowser(browserImpl, {
-      _sharedBrowser: true,
-      ...options
-    });
-  }
   async startTracing(page, options = {}) {
     this._path = options.path;
     await this._channel.startTracing({ ...options, page: page ? page._channel : void 0 });
