@@ -78,6 +78,9 @@ const Events = {
     WebSocket: "websocket",
     Worker: "worker"
   },
+  PageAgent: {
+    Turn: "turn"
+  },
   WebSocket: {
     Close: "close",
     Error: "socketerror",
@@ -85,7 +88,8 @@ const Events = {
     FrameSent: "framesent"
   },
   Worker: {
-    Close: "close"
+    Close: "close",
+    Console: "console"
   },
   ElectronApplication: {
     Close: "close",
