@@ -22,10 +22,10 @@ __export(chromiumSwitches_exports, {
 });
 module.exports = __toCommonJS(chromiumSwitches_exports);
 const disabledFeatures = (assistantMode) => [
-  // See https://github.com/microsoft/playwright/pull/10380
-  "AcceptCHFrame",
   // See https://github.com/microsoft/playwright/issues/14047
   "AvoidUnnecessaryBeforeUnloadCheckSync",
+  // See https://github.com/microsoft/playwright/issues/38568
+  "BoundaryEventDispatchTracksNodeRemoval",
   "DestroyProfileOnBrowserClose",
   // See https://github.com/microsoft/playwright/pull/13854
   "DialMediaRouteProvider",
