@@ -284,11 +284,12 @@ class CRBrowser extends import_browser.Browser {
     return this._clientRootSessionPromise;
   }
 }
+const CREvents = {
+  ServiceWorker: "serviceworker"
+};
 class CRBrowserContext extends import_browserContext.BrowserContext {
   static {
-    this.CREvents = {
-      ServiceWorker: "serviceworker"
-    };
+    this.CREvents = CREvents;
   }
   constructor(browser, browserContextId, options) {
     super(browser, options, browserContextId);
@@ -388,13 +389,13 @@ class CRBrowserContext extends import_browserContext.BrowserContext {
       ["midi-sysex", "midiSysex"],
       ["storage-access", "storageAccess"],
       ["local-fonts", "localFonts"],
-      ["local-network-access", "localNetworkAccess"]
+      ["local-network-access", ["localNetworkAccess", "localNetwork", "loopbackNetwork"]]
     ]);
-    const filtered = permissions.map((permission) => {
+    const filtered = permissions.flatMap((permission) => {
       const protocolPermission = webPermissionToProtocol.get(permission);
       if (!protocolPermission)
         throw new Error("Unknown permission: " + permission);
-      return protocolPermission;
+      return typeof protocolPermission === "string" ? [protocolPermission] : protocolPermission;
     });
     await this._browser._session.send("Browser.grantPermissions", { origin: origin === "*" ? void 0 : origin, browserContextId: this._browserContextId, permissions: filtered });
   }
@@ -470,7 +471,7 @@ class CRBrowserContext extends import_browserContext.BrowserContext {
     }
   }
   async stopVideoRecording() {
-    await Promise.all(this._crPages().map((crPage) => crPage._mainFrameSession._stopVideoRecording()));
+    await Promise.all(this._crPages().map((crPage) => crPage._page.screencast.stopVideoRecording()));
   }
   onClosePersistent() {
   }
