@@ -98,7 +98,7 @@ class FrameDispatcher extends import_dispatcher.Dispatcher {
     return { elements: elements.map((e) => import_elementHandlerDispatcher.ElementHandleDispatcher.from(this, e)) };
   }
   async queryCount(params, progress) {
-    return { value: await progress.race(this._frame.queryCount(params.selector)) };
+    return { value: await progress.race(this._frame.queryCount(params.selector, params)) };
   }
   async content(params, progress) {
     return { value: await progress.race(this._frame.content()) };
@@ -144,8 +144,8 @@ class FrameDispatcher extends import_dispatcher.Dispatcher {
   async innerHTML(params, progress) {
     return { value: await this._frame.innerHTML(progress, params.selector, params) };
   }
-  async generateLocatorString(params, progress) {
-    return { value: await this._frame.generateLocatorString(progress, params.selector) };
+  async resolveSelector(params, progress) {
+    return await this._frame.resolveSelector(progress, params.selector);
   }
   async getAttribute(params, progress) {
     const value = await this._frame.getAttribute(progress, params.selector, params.name, params);
@@ -212,17 +212,13 @@ class FrameDispatcher extends import_dispatcher.Dispatcher {
     let expectedValue = params.expectedValue ? (0, import_jsHandleDispatcher.parseArgument)(params.expectedValue) : void 0;
     if (params.expression === "to.match.aria" && expectedValue)
       expectedValue = (0, import_ariaSnapshot.parseAriaSnapshotUnsafe)(import_utilsBundle.yaml, expectedValue);
-    const result = await this._frame.expect(progress, params.selector, { ...params, expectedValue }, params.timeout, (result2) => {
-      if (result2.received !== void 0)
-        result2.received = (0, import_jsHandleDispatcher.serializeResult)(result2.received);
-      return result2;
-    });
+    const result = await this._frame.expect(progress, params.selector, { ...params, expectedValue, timeoutForLogs: params.timeout });
     if (result.received !== void 0)
       result.received = (0, import_jsHandleDispatcher.serializeResult)(result.received);
     return result;
   }
   async ariaSnapshot(params, progress) {
-    return { snapshot: await this._frame.ariaSnapshot(progress, params.selector, params) };
+    return { snapshot: await this._frame.ariaSnapshot(progress, params.selector) };
   }
 }
 // Annotate the CommonJS export names for ESM import in node:
