@@ -19,131 +19,87 @@ var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: tru
 var progress_exports = {};
 __export(progress_exports, {
   ProgressController: () => ProgressController,
-  isAbortError: () => isAbortError
+  isAbortError: () => isAbortError,
+  raceUncancellableOperationWithCleanup: () => raceUncancellableOperationWithCleanup
 });
 module.exports = __toCommonJS(progress_exports);
 var import_errors = require("./errors");
 var import_utils = require("../utils");
 var import_manualPromise = require("../utils/isomorphic/manualPromise");
 class ProgressController {
-  constructor(metadata, sdkObject) {
+  constructor(metadata, onCallLog) {
     this._forceAbortPromise = new import_manualPromise.ManualPromise();
     this._donePromise = new import_manualPromise.ManualPromise();
-    // Cleanups to be run only in the case of abort.
-    this._cleanups = [];
-    // Lenient mode races against the timeout. This guarantees that timeout is respected,
-    // but may have some work being done after the timeout due to parallel control flow.
-    //
-    // Strict mode aborts the progress and requires the code to react to it. This way,
-    // progress only finishes after the inner callback exits, guaranteeing no work after the timeout.
-    this._strictMode = false;
     this._state = "before";
-    this._strictMode = !process.env.PLAYWRIGHT_LEGACY_TIMEOUTS;
-    this.metadata = metadata;
-    this.sdkObject = sdkObject;
-    this.instrumentation = sdkObject.instrumentation;
-    this._logName = sdkObject.logName || "api";
+    this.metadata = metadata || { id: "", startTime: 0, endTime: 0, type: "Internal", method: "", params: {}, log: [], internal: true };
+    this._onCallLog = onCallLog;
     this._forceAbortPromise.catch((e) => null);
+    this._controller = new AbortController();
   }
-  setLogName(logName) {
-    this._logName = logName;
+  static createForSdkObject(sdkObject, callMetadata) {
+    const logName = sdkObject.logName || "api";
+    return new ProgressController(callMetadata, (message) => {
+      import_utils.debugLogger.log(logName, message);
+      sdkObject.instrumentation.onCallLog(sdkObject, callMetadata, logName, message);
+    });
   }
   async abort(error) {
     if (this._state === "running") {
       error[kAbortErrorSymbol] = true;
       this._state = { error };
       this._forceAbortPromise.reject(error);
+      this._controller.abort(error);
     }
-    if (this._strictMode)
-      await this._donePromise;
+    await this._donePromise;
   }
   async run(task, timeout) {
+    const deadline = timeout ? (0, import_utils.monotonicTime)() + timeout : 0;
     (0, import_utils.assert)(this._state === "before");
     this._state = "running";
-    let customErrorHandler;
-    const deadline = timeout ? Math.min((0, import_utils.monotonicTime)() + timeout, 2147483647) : 0;
-    const timeoutError = new import_errors.TimeoutError(`Timeout ${timeout}ms exceeded.`);
     let timer;
-    const startTimer = () => {
-      if (!deadline)
-        return;
-      const onTimeout = () => {
-        if (this._state === "running") {
-          timeoutError[kAbortErrorSymbol] = true;
-          this._state = { error: timeoutError };
-          this._forceAbortPromise.reject(timeoutError);
-        }
-      };
-      const remaining = deadline - (0, import_utils.monotonicTime)();
-      if (remaining <= 0)
-        onTimeout();
-      else
-        timer = setTimeout(onTimeout, remaining);
-    };
     const progress = {
+      timeout: timeout ?? 0,
+      deadline,
+      disableTimeout: () => {
+        clearTimeout(timer);
+      },
       log: (message) => {
         if (this._state === "running")
           this.metadata.log.push(message);
-        this.instrumentation.onCallLog(this.sdkObject, this.metadata, this._logName, message);
-      },
-      cleanupWhenAborted: (cleanup) => {
-        if (this._strictMode) {
-          if (this._state !== "running")
-            throw new Error("Internal error: cannot register cleanup after operation has finished.");
-          this._cleanups.push(cleanup);
-          return;
-        }
-        if (this._state === "running")
-          this._cleanups.push(cleanup);
-        else
-          runCleanup(typeof this._state === "object" ? this._state.error : void 0, cleanup);
+        this._onCallLog?.(message);
       },
       metadata: this.metadata,
       race: (promise) => {
         const promises = Array.isArray(promise) ? promise : [promise];
+        if (!promises.length)
+          return Promise.resolve();
         return Promise.race([...promises, this._forceAbortPromise]);
       },
-      raceWithCleanup: (promise, cleanup) => {
-        return progress.race(promise.then((result) => {
-          if (this._state !== "running")
-            cleanup(result);
-          else
-            this._cleanups.push(() => cleanup(result));
-          return result;
-        }));
-      },
       wait: async (timeout2) => {
         let timer2;
         const promise = new Promise((f) => timer2 = setTimeout(f, timeout2));
         return progress.race(promise).finally(() => clearTimeout(timer2));
       },
-      legacyDisableTimeout: () => {
-        if (this._strictMode)
-          return;
-        clearTimeout(timer);
-      },
-      legacyEnableTimeout: () => {
-        if (this._strictMode)
-          return;
-        startTimer();
-      },
-      legacySetErrorHandler: (handler) => {
-        if (this._strictMode)
-          return;
-        customErrorHandler = handler;
-      }
+      signal: this._controller.signal
     };
-    startTimer();
+    if (deadline) {
+      const timeoutError = new import_errors.TimeoutError(`Timeout ${timeout}ms exceeded.`);
+      timer = setTimeout(() => {
+        if (this.metadata.pauseStartTime && !this.metadata.pauseEndTime)
+          return;
+        if (this._state === "running") {
+          this._state = { error: timeoutError };
+          this._forceAbortPromise.reject(timeoutError);
+          this._controller.abort(timeoutError);
+        }
+      }, deadline - (0, import_utils.monotonicTime)());
+    }
     try {
-      const promise = task(progress);
-      const result = this._strictMode ? await promise : await Promise.race([promise, this._forceAbortPromise]);
+      const result = await task(progress);
       this._state = "finished";
       return result;
     } catch (error) {
       this._state = { error };
-      await Promise.all(this._cleanups.splice(0).map((cleanup) => runCleanup(error, cleanup)));
-      if (customErrorHandler)
-        return customErrorHandler(error);
       throw error;
     } finally {
       clearTimeout(timer);
@@ -151,18 +107,26 @@ class ProgressController {
     }
   }
 }
-async function runCleanup(error, cleanup) {
-  try {
-    await cleanup(error);
-  } catch (e) {
-  }
-}
 const kAbortErrorSymbol = Symbol("kAbortError");
 function isAbortError(error) {
-  return !!error[kAbortErrorSymbol];
+  return error instanceof import_errors.TimeoutError || !!error[kAbortErrorSymbol];
+}
+async function raceUncancellableOperationWithCleanup(progress, run, cleanup) {
+  let aborted = false;
+  try {
+    return await progress.race(run().then(async (t) => {
+      if (aborted)
+        await cleanup(t);
+      return t;
+    }));
+  } catch (error) {
+    aborted = true;
+    throw error;
+  }
 }
 // Annotate the CommonJS export names for ESM import in node:
 0 && (module.exports = {
   ProgressController,
-  isAbortError
+  isAbortError,
+  raceUncancellableOperationWithCleanup
 });
