@@ -35,7 +35,8 @@ __export(network_exports, {
   createProxyAgent: () => createProxyAgent,
   fetchData: () => fetchData,
   httpRequest: () => httpRequest,
-  isURLAvailable: () => isURLAvailable
+  isURLAvailable: () => isURLAvailable,
+  startHttpServer: () => startHttpServer
 });
 module.exports = __toCommonJS(network_exports);
 var import_http = __toESM(require("http"));
@@ -43,11 +44,11 @@ var import_http2 = __toESM(require("http2"));
 var import_https = __toESM(require("https"));
 var import_utilsBundle = require("../../utilsBundle");
 var import_happyEyeballs = require("./happyEyeballs");
+var import_manualPromise = require("../../utils/isomorphic/manualPromise");
 const NET_DEFAULT_TIMEOUT = 3e4;
 function httpRequest(params, onResponse, onError) {
-  const parsedUrl = new URL(params.url);
+  let url = new URL(params.url);
   const options = {
-    agent: parsedUrl.protocol === "https:" ? import_happyEyeballs.httpsHappyEyeballsAgent : import_happyEyeballs.httpHappyEyeballsAgent,
     method: params.method || "GET",
     headers: params.headers
   };
@@ -55,18 +56,16 @@ function httpRequest(params, onResponse, onError) {
     options.rejectUnauthorized = params.rejectUnauthorized;
   const proxyURL = (0, import_utilsBundle.getProxyForUrl)(params.url);
   if (proxyURL) {
-    const parsedProxyURL = new URL(proxyURL);
+    const parsedProxyURL = normalizeProxyURL(proxyURL);
     if (params.url.startsWith("http:")) {
-      parsedUrl.pathname = parsedUrl.href;
-      parsedUrl.host = parsedProxyURL.host;
+      parsedProxyURL.pathname = url.toString();
+      url = parsedProxyURL;
     } else {
-      options.agent = new import_utilsBundle.HttpsProxyAgent({
-        ...convertURLtoLegacyUrl(parsedProxyURL),
-        secureProxy: parsedProxyURL.protocol === "https:"
-      });
+      options.agent = new import_utilsBundle.HttpsProxyAgent(parsedProxyURL);
       options.rejectUnauthorized = false;
     }
   }
+  options.agent ??= url.protocol === "https:" ? import_happyEyeballs.httpsHappyEyeballsAgent : import_happyEyeballs.httpHappyEyeballsAgent;
   let cancelRequest;
   const requestCallback = (res) => {
     const statusCode = res.statusCode || 0;
@@ -77,7 +76,7 @@ function httpRequest(params, onResponse, onError) {
       onResponse(res);
     }
   };
-  const request = options.protocol === "https:" ? import_https.default.request(parsedUrl, options, requestCallback) : import_http.default.request(parsedUrl, options, requestCallback);
+  const request = url.protocol === "https:" ? import_https.default.request(url, options, requestCallback) : import_http.default.request(url, options, requestCallback);
   request.on("error", onError);
   if (params.socketTimeout !== void 0) {
     request.setTimeout(params.socketTimeout, () => {
@@ -85,28 +84,38 @@ function httpRequest(params, onResponse, onError) {
       request.abort();
     });
   }
-  cancelRequest = (e) => request.destroy(e);
+  cancelRequest = (e) => {
+    try {
+      request.destroy(e);
+    } catch {
+    }
+  };
   request.end(params.data);
   return { cancel: (e) => cancelRequest(e) };
 }
-function fetchData(progress, params, onError) {
-  const promise = new Promise((resolve, reject) => {
-    const { cancel } = httpRequest(params, async (response) => {
-      if (response.statusCode !== 200) {
-        const error = onError ? await onError(params, response) : new Error(`fetch failed: server returned code ${response.statusCode}. URL: ${params.url}`);
-        reject(error);
-        return;
-      }
-      let body = "";
-      response.on("data", (chunk) => body += chunk);
-      response.on("error", (error) => reject(error));
-      response.on("end", () => resolve(body));
-    }, reject);
-    progress?.cleanupWhenAborted(cancel);
-  });
-  return progress ? progress.race(promise) : promise;
+async function fetchData(progress, params, onError) {
+  const promise = new import_manualPromise.ManualPromise();
+  const { cancel } = httpRequest(params, async (response) => {
+    if (response.statusCode !== 200) {
+      const error = onError ? await onError(params, response) : new Error(`fetch failed: server returned code ${response.statusCode}. URL: ${params.url}`);
+      promise.reject(error);
+      return;
+    }
+    let body = "";
+    response.on("data", (chunk) => body += chunk);
+    response.on("error", (error) => promise.reject(error));
+    response.on("end", () => promise.resolve(body));
+  }, (error) => promise.reject(error));
+  if (!progress)
+    return promise;
+  try {
+    return await progress.race(promise);
+  } catch (error) {
+    cancel(error);
+    throw error;
+  }
 }
-function shouldBypassProxy(url2, bypass) {
+function shouldBypassProxy(url, bypass) {
   if (!bypass)
     return false;
   const domains = bypass.split(",").map((s) => {
@@ -115,32 +124,36 @@ function shouldBypassProxy(url2, bypass) {
       s = "." + s;
     return s;
   });
-  const domain = "." + url2.hostname;
+  const domain = "." + url.hostname;
   return domains.some((d) => domain.endsWith(d));
 }
+function normalizeProxyURL(proxy) {
+  proxy = proxy.trim();
+  if (!/^\w+:\/\//.test(proxy))
+    proxy = "http://" + proxy;
+  return new URL(proxy);
+}
 function createProxyAgent(proxy, forUrl) {
   if (!proxy)
     return;
   if (forUrl && proxy.bypass && shouldBypassProxy(forUrl, proxy.bypass))
     return;
-  let proxyServer = proxy.server.trim();
-  if (!/^\w+:\/\//.test(proxyServer))
-    proxyServer = "http://" + proxyServer;
-  const proxyOpts = new URL(proxyServer);
-  if (proxyOpts.protocol?.startsWith("socks")) {
-    return new import_utilsBundle.SocksProxyAgent({
-      host: proxyOpts.hostname,
-      port: proxyOpts.port || void 0
-    });
+  const proxyURL = normalizeProxyURL(proxy.server);
+  if (proxyURL.protocol?.startsWith("socks")) {
+    if (proxyURL.protocol === "socks5:")
+      proxyURL.protocol = "socks5h:";
+    else if (proxyURL.protocol === "socks4:")
+      proxyURL.protocol = "socks4a:";
+    return new import_utilsBundle.SocksProxyAgent(proxyURL);
   }
   if (proxy.username) {
-    proxyOpts.username = proxy.username;
-    proxyOpts.password = proxy.password || "";
+    proxyURL.username = proxy.username;
+    proxyURL.password = proxy.password || "";
   }
   if (forUrl && ["ws:", "wss:"].includes(forUrl.protocol)) {
-    return new import_utilsBundle.HttpsProxyAgent(convertURLtoLegacyUrl(proxyOpts));
+    return new import_utilsBundle.HttpsProxyAgent(proxyURL);
   }
-  return new import_utilsBundle.HttpsProxyAgent(convertURLtoLegacyUrl(proxyOpts));
+  return new import_utilsBundle.HttpsProxyAgent(proxyURL);
 }
 function createHttpServer(...args) {
   const server = import_http.default.createServer(...args);
@@ -157,20 +170,35 @@ function createHttp2Server(...args) {
   decorateServer(server);
   return server;
 }
-async function isURLAvailable(url2, ignoreHTTPSErrors, onLog, onStdErr) {
-  let statusCode = await httpStatusCode(url2, ignoreHTTPSErrors, onLog, onStdErr);
-  if (statusCode === 404 && url2.pathname === "/") {
-    const indexUrl = new URL(url2);
+async function startHttpServer(server, options) {
+  const { host = "localhost", port = 0 } = options;
+  const errorPromise = new import_manualPromise.ManualPromise();
+  const errorListener = (error) => errorPromise.reject(error);
+  server.on("error", errorListener);
+  try {
+    server.listen(port, host);
+    await Promise.race([
+      new Promise((cb) => server.once("listening", cb)),
+      errorPromise
+    ]);
+  } finally {
+    server.removeListener("error", errorListener);
+  }
+}
+async function isURLAvailable(url, ignoreHTTPSErrors, onLog, onStdErr) {
+  let statusCode = await httpStatusCode(url, ignoreHTTPSErrors, onLog, onStdErr);
+  if (statusCode === 404 && url.pathname === "/") {
+    const indexUrl = new URL(url);
     indexUrl.pathname = "/index.html";
     statusCode = await httpStatusCode(indexUrl, ignoreHTTPSErrors, onLog, onStdErr);
   }
   return statusCode >= 200 && statusCode < 404;
 }
-async function httpStatusCode(url2, ignoreHTTPSErrors, onLog, onStdErr) {
+async function httpStatusCode(url, ignoreHTTPSErrors, onLog, onStdErr) {
   return new Promise((resolve) => {
-    onLog?.(`HTTP GET: ${url2}`);
+    onLog?.(`HTTP GET: ${url}`);
     httpRequest({
-      url: url2.toString(),
+      url: url.toString(),
       headers: { Accept: "*/*" },
       rejectUnauthorized: !ignoreHTTPSErrors
     }, (res) => {
@@ -181,7 +209,7 @@ async function httpStatusCode(url2, ignoreHTTPSErrors, onLog, onStdErr) {
     }, (error) => {
       if (error.code === "DEPTH_ZERO_SELF_SIGNED_CERT")
         onStdErr?.(`[WebServer] Self-signed certificate detected. Try adding ignoreHTTPSErrors: true to config.webServer.`);
-      onLog?.(`Error while checking if ${url2} is available: ${error.message}`);
+      onLog?.(`Error while checking if ${url} is available: ${error.message}`);
       resolve(0);
     });
   });
@@ -200,22 +228,6 @@ function decorateServer(server) {
     return close.call(server, callback);
   };
 }
-function convertURLtoLegacyUrl(url2) {
-  return {
-    auth: url2.username ? url2.username + ":" + url2.password : null,
-    hash: url2.hash || null,
-    host: url2.hostname ? url2.hostname + ":" + url2.port : null,
-    hostname: url2.hostname || null,
-    href: url2.href,
-    path: url2.pathname + url2.search,
-    pathname: url2.pathname,
-    protocol: url2.protocol,
-    search: url2.search || null,
-    slashes: true,
-    port: url2.port || null,
-    query: url2.search.slice(1) || null
-  };
-}
 // Annotate the CommonJS export names for ESM import in node:
 0 && (module.exports = {
   NET_DEFAULT_TIMEOUT,
@@ -225,5 +237,6 @@ function convertURLtoLegacyUrl(url2) {
   createProxyAgent,
   fetchData,
   httpRequest,
-  isURLAvailable
+  isURLAvailable,
+  startHttpServer
 });
