@@ -31,10 +31,8 @@ __export(wkPage_exports, {
   WKPage: () => WKPage
 });
 module.exports = __toCommonJS(wkPage_exports);
-var import_path = __toESM(require("path"));
 var import_utils = require("../../utils");
 var import_headers = require("../../utils/isomorphic/headers");
-var import_crypto = require("../utils/crypto");
 var import_eventsHelper = require("../utils/eventsHelper");
 var import_hostPlatform = require("../utils/hostPlatform");
 var import_stackTrace = require("../../utils/isomorphic/stackTrace");
@@ -51,12 +49,13 @@ var import_wkInput = require("./wkInput");
 var import_wkInterceptableRequest = require("./wkInterceptableRequest");
 var import_wkProvisionalPage = require("./wkProvisionalPage");
 var import_wkWorkers = require("./wkWorkers");
-var import_debugLogger = require("../utils/debugLogger");
 var import_webkit = require("./webkit");
 const UTILITY_WORLD_NAME = "__playwright_utility_world__";
+const enableFrameSessions = !process.env.WK_DISABLE_FRAME_SESSIONS;
 class WKPage {
   constructor(browserContext, pageProxySession, opener) {
     this._provisionalPage = null;
+    this._targetIdToFrameSession = /* @__PURE__ */ new Map();
     this._requestIdToRequest = /* @__PURE__ */ new Map();
     this._requestIdToRequestWillBeSentEvent = /* @__PURE__ */ new Map();
     this._sessionListeners = [];
@@ -66,7 +65,6 @@ class WKPage {
     };
     this._lastConsoleMessage = null;
     this._requestIdToResponseReceivedPayloadEvent = /* @__PURE__ */ new Map();
-    this._recordingVideoFile = null;
     this._screencastGeneration = 0;
     this._pageProxySession = pageProxySession;
     this._opener = opener;
@@ -116,16 +114,7 @@ class WKPage {
       for (const [key, value] of this._browserContext._permissions)
         promises.push(this._grantPermissions(key, value));
     }
-    if (this._browserContext._options.recordVideo) {
-      const outputFile = import_path.default.join(this._browserContext._options.recordVideo.dir, (0, import_crypto.createGuid)() + ".webm");
-      promises.push(this._browserContext._ensureVideosPath().then(() => {
-        return this._startVideo({
-          // validateBrowserContextOptions ensures correct video size.
-          ...this._browserContext._options.recordVideo.size,
-          outputFile
-        });
-      }));
-    }
+    promises.push(this._initializeVideoRecording());
     await Promise.all(promises);
   }
   _setSession(session) {
@@ -159,10 +148,13 @@ class WKPage {
       session.send("Page.createUserWorld", { name: UTILITY_WORLD_NAME }).catch((_) => {
       }),
       // Worlds are per-process
-      session.send("Console.enable"),
       session.send("Network.enable"),
       this._workers.initializeSession(session)
     ];
+    if (enableFrameSessions)
+      this._initializeFrameSessions(frameTree.frameTree, promises);
+    else
+      promises.push(session.send("Console.enable"));
     if (this._page.browserContext.needsPlaywrightBinding())
       promises.push(session.send("Runtime.addBinding", { name: import_page.PageBinding.kBindingName }));
     if (this._page.needsRequestInterception()) {
@@ -219,6 +211,13 @@ class WKPage {
     promises.push(session.send("Page.overrideSetting", { setting: "FixedBackgroundsPaintRelativeToDocument", value: contextOptions.isMobile }));
     await Promise.all(promises);
   }
+  _initializeFrameSessions(frame, promises) {
+    const session = this._targetIdToFrameSession.get(`frame-${frame.frame.id}`);
+    if (session)
+      promises.push(session.initialize());
+    for (const childFrame of frame.childFrames || [])
+      this._initializeFrameSessions(childFrame, promises);
+  }
   _onDidCommitProvisionalTarget(event) {
     const { oldTargetId, newTargetId } = event;
     (0, import_utils.assert)(this._provisionalPage);
@@ -244,6 +243,9 @@ class WKPage {
         this._session.markAsCrashed();
         this._page._didCrash();
       }
+    } else if (this._targetIdToFrameSession.has(targetId)) {
+      this._targetIdToFrameSession.get(targetId).dispose();
+      this._targetIdToFrameSession.delete(targetId);
     }
   }
   didClose() {
@@ -257,7 +259,7 @@ class WKPage {
       this._provisionalPage.dispose();
       this._provisionalPage = null;
     }
-    this._firstNonInitialNavigationCommittedReject(new import_errors.TargetClosedError());
+    this._firstNonInitialNavigationCommittedReject(new import_errors.TargetClosedError(this._page.closeReason()));
     this._page._didClose();
   }
   dispatchMessageToSession(message) {
@@ -288,8 +290,15 @@ class WKPage {
         session.dispatchMessage({ id: message.id, error: { message: e.message } });
       });
     });
-    if (targetInfo.type === "frame")
+    if (targetInfo.type === "frame") {
+      if (enableFrameSessions) {
+        const wkFrame = new WKFrame(this, session);
+        this._targetIdToFrameSession.set(targetInfo.targetId, wkFrame);
+        await wkFrame.initialize().catch((e) => {
+        });
+      }
       return;
+    }
     (0, import_utils.assert)(targetInfo.type === "page", "Only page targets are expected in WebKit, received: " + targetInfo.type);
     if (!targetInfo.isProvisional) {
       (0, import_utils.assert)(!this._page.initializedOrUndefined());
@@ -331,6 +340,8 @@ class WKPage {
       this._provisionalPage._session.dispatchMessage(JSON.parse(message));
     else if (this._session.sessionId === targetId)
       this._session.dispatchMessage(JSON.parse(message));
+    else if (this._targetIdToFrameSession.has(targetId))
+      this._targetIdToFrameSession.get(targetId)._session.dispatchMessage(JSON.parse(message));
     else
       throw new Error("Unknown target: " + targetId);
   }
@@ -453,7 +464,7 @@ class WKPage {
   }
   async navigateFrame(frame, url, referrer) {
     if (this._pageProxySession.isDisposed())
-      throw new import_errors.TargetClosedError();
+      throw new import_errors.TargetClosedError(this._page.closeReason());
     const pageProxyId = this._pageProxySession.sessionId;
     const result = await this._pageProxySession.connection.browserSession.send("Playwright.navigate", { url, pageProxyId, frameId: frame._id, referrer });
     return { newDocumentId: result.loaderId };
@@ -748,7 +759,6 @@ class WKPage {
     await this._updateState("Page.setBootstrapScript", { source: this._calculateBootstrapScript() });
   }
   async closePage(runBeforeUnload) {
-    await this._stopVideo();
     await this._pageProxySession.sendMayFail("Target.close", {
       targetId: this._session.sessionId,
       runBeforeUnload
@@ -762,22 +772,11 @@ class WKPage {
       return import_hostPlatform.hostPlatform === "mac10.15" ? 55 : 59;
     return 0;
   }
-  async _startVideo(options) {
-    (0, import_utils.assert)(!this._recordingVideoFile);
-    const { screencastId } = await this._pageProxySession.send("Screencast.startVideo", {
-      file: this._browserContext._browser.options.channel === "webkit-wsl" ? await (0, import_webkit.translatePathToWSL)(options.outputFile) : options.outputFile,
-      width: options.width,
-      height: options.height,
-      toolbarHeight: this._toolbarHeight()
-    });
-    this._recordingVideoFile = options.outputFile;
-    this._browserContext._browser._videoStarted(this._browserContext, screencastId, options.outputFile, this._page.waitForInitializedOrError());
-  }
-  async _stopVideo() {
-    if (!this._recordingVideoFile)
-      return;
-    await this._pageProxySession.sendMayFail("Screencast.stopVideo");
-    this._recordingVideoFile = null;
+  async _initializeVideoRecording() {
+    const screencast = this._page.screencast;
+    const videoOptions = screencast.launchVideoRecorder();
+    if (videoOptions)
+      await screencast.startVideoRecording(videoOptions);
   }
   validateScreenshotDimension(side, omitDeviceScaleFactor) {
     if (process.platform === "darwin")
@@ -845,23 +844,27 @@ class WKPage {
       throw e;
     });
   }
-  async setScreencastOptions(options) {
-    if (options) {
-      const so = { ...options, toolbarHeight: this._toolbarHeight() };
-      const { generation } = await this._pageProxySession.send("Screencast.startScreencast", so);
-      this._screencastGeneration = generation;
-    } else {
-      await this._pageProxySession.send("Screencast.stopScreencast");
-    }
+  async startScreencast(options) {
+    const { generation } = await this._pageProxySession.send("Screencast.startScreencast", {
+      quality: options.quality,
+      width: options.width,
+      height: options.height,
+      toolbarHeight: this._toolbarHeight()
+    });
+    this._screencastGeneration = generation;
+  }
+  async stopScreencast() {
+    await this._pageProxySession.sendMayFail("Screencast.stopScreencast");
   }
   _onScreencastFrame(event) {
     const generation = this._screencastGeneration;
-    this._page.throttleScreencastFrameAck(() => {
-      this._pageProxySession.send("Screencast.screencastFrameAck", { generation }).catch((e) => import_debugLogger.debugLogger.log("error", e));
+    this._page.screencast.throttleFrameAck(() => {
+      this._pageProxySession.sendMayFail("Screencast.screencastFrameAck", { generation });
     });
     const buffer = Buffer.from(event.data, "base64");
     this._page.emit(import_page.Page.Events.ScreencastFrame, {
       buffer,
+      frameSwapWallTime: event.timestamp ? event.timestamp * 1e3 : Date.now(),
       width: event.deviceWidth,
       height: event.deviceHeight
     });
@@ -886,7 +889,7 @@ class WKPage {
     const pageProxyId = this._pageProxySession.sessionId;
     const objectId = handle._objectId;
     if (this._browserContext._browser?.options.channel === "webkit-wsl")
-      paths = await Promise.all(paths.map((path2) => (0, import_webkit.translatePathToWSL)(path2)));
+      paths = await Promise.all(paths.map((path) => (0, import_webkit.translatePathToWSL)(path)));
     await Promise.all([
       this._pageProxySession.connection.browserSession.send("Playwright.grantFileReadAccess", { pageProxyId, paths }),
       this._session.send("DOM.setInputFiles", { objectId, paths })
@@ -1085,6 +1088,31 @@ class WKPage {
     return true;
   }
 }
+class WKFrame {
+  constructor(page, session) {
+    this._sessionListeners = [];
+    this._initializePromise = null;
+    this._page = page;
+    this._session = session;
+  }
+  async initialize() {
+    if (this._initializePromise)
+      return this._initializePromise;
+    this._initializePromise = this._initializeImpl();
+    return this._initializePromise;
+  }
+  async _initializeImpl() {
+    this._sessionListeners = [
+      import_eventsHelper.eventsHelper.addEventListener(this._session, "Console.messageAdded", (event) => this._page._onConsoleMessage(event)),
+      import_eventsHelper.eventsHelper.addEventListener(this._session, "Console.messageRepeatCountUpdated", (event) => this._page._onConsoleRepeatCountUpdated(event))
+    ];
+    await this._session.send("Console.enable");
+  }
+  dispose() {
+    import_eventsHelper.eventsHelper.removeEventListeners(this._sessionListeners);
+    this._session.dispose();
+  }
+}
 function parseRemoteAddress(value) {
   if (!value)
     return;
