@@ -67,9 +67,11 @@ const methodMetainfo = /* @__PURE__ */ new Map([
   ["EventTarget.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
   ["BrowserContext.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
   ["Page.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
+  ["Worker.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
   ["WebSocket.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
   ["ElectronApplication.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
   ["AndroidDevice.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
+  ["PageAgent.waitForEventInfo", { title: 'Wait for event "{info.event}"', snapshot: true }],
   ["BrowserContext.addCookies", { title: "Add cookies", group: "configuration" }],
   ["BrowserContext.addInitScript", { title: "Add init script", group: "configuration" }],
   ["BrowserContext.clearCookies", { title: "Clear cookies", group: "configuration" }],
@@ -91,6 +93,7 @@ const methodMetainfo = /* @__PURE__ */ new Map([
   ["BrowserContext.pause", { title: "Pause" }],
   ["BrowserContext.enableRecorder", { internal: true }],
   ["BrowserContext.disableRecorder", { internal: true }],
+  ["BrowserContext.exposeConsoleApi", { internal: true }],
   ["BrowserContext.newCDPSession", { title: "Create CDP session", group: "configuration" }],
   ["BrowserContext.harStart", { internal: true }],
   ["BrowserContext.harExport", { internal: true }],
@@ -105,6 +108,7 @@ const methodMetainfo = /* @__PURE__ */ new Map([
   ["BrowserContext.clockSetSystemTime", { title: 'Set system time "{timeNumber|timeString}"' }],
   ["Page.addInitScript", { title: "Add init script", group: "configuration" }],
   ["Page.close", { title: "Close page", pausesBeforeAction: true }],
+  ["Page.consoleMessages", { title: "Get console messages", group: "getter" }],
   ["Page.emulateMedia", { title: "Emulate media", snapshot: true, pausesBeforeAction: true }],
   ["Page.exposeBinding", { title: "Expose binding", group: "configuration" }],
   ["Page.goBack", { title: "Go back", slowMo: true, snapshot: true, pausesBeforeAction: true }],
@@ -131,8 +135,9 @@ const methodMetainfo = /* @__PURE__ */ new Map([
   ["Page.mouseClick", { title: "Click", slowMo: true, snapshot: true, pausesBeforeAction: true }],
   ["Page.mouseWheel", { title: "Mouse wheel", slowMo: true, snapshot: true, pausesBeforeAction: true }],
   ["Page.touchscreenTap", { title: "Tap", slowMo: true, snapshot: true, pausesBeforeAction: true }],
-  ["Page.accessibilitySnapshot", { title: "Accessibility snapshot", group: "getter" }],
+  ["Page.pageErrors", { title: "Get page errors", group: "getter" }],
   ["Page.pdf", { title: "PDF" }],
+  ["Page.requests", { title: "Get network requests", group: "getter" }],
   ["Page.snapshotForAI", { internal: true }],
   ["Page.startJSCoverage", { title: "Start JS coverage", group: "configuration" }],
   ["Page.stopJSCoverage", { title: "Stop JS coverage", group: "configuration" }],
@@ -140,6 +145,7 @@ const methodMetainfo = /* @__PURE__ */ new Map([
   ["Page.stopCSSCoverage", { title: "Stop CSS coverage", group: "configuration" }],
   ["Page.bringToFront", { title: "Bring to front" }],
   ["Page.updateSubscription", { internal: true }],
+  ["Page.agent", { internal: true }],
   ["Frame.evalOnSelector", { title: "Evaluate", snapshot: true, pausesBeforeAction: true }],
   ["Frame.evalOnSelectorAll", { title: "Evaluate", snapshot: true, pausesBeforeAction: true }],
   ["Frame.addScriptTag", { title: "Add script tag", snapshot: true, pausesBeforeAction: true }],
@@ -189,6 +195,7 @@ const methodMetainfo = /* @__PURE__ */ new Map([
   ["Frame.expect", { title: 'Expect "{expression}"', snapshot: true, pausesBeforeAction: true }],
   ["Worker.evaluateExpression", { title: "Evaluate" }],
   ["Worker.evaluateExpressionHandle", { title: "Evaluate" }],
+  ["Worker.updateSubscription", { internal: true }],
   ["JSHandle.dispose", { internal: true }],
   ["ElementHandle.dispose", { internal: true }],
   ["JSHandle.evaluateExpression", { title: "Evaluate", snapshot: true, pausesBeforeAction: true }],
@@ -310,7 +317,12 @@ const methodMetainfo = /* @__PURE__ */ new Map([
   ["AndroidDevice.connectToWebView", { title: "Connect to Web View" }],
   ["AndroidDevice.close", { internal: true }],
   ["JsonPipe.send", { internal: true }],
-  ["JsonPipe.close", { internal: true }]
+  ["JsonPipe.close", { internal: true }],
+  ["PageAgent.perform", { title: 'Perform "{task}"' }],
+  ["PageAgent.expect", { title: 'Expect "{expectation}"' }],
+  ["PageAgent.extract", { title: 'Extract "{query}"' }],
+  ["PageAgent.dispose", { internal: true }],
+  ["PageAgent.usage", { title: "Get agent usage", group: "configuration" }]
 ]);
 // Annotate the CommonJS export names for ESM import in node:
 0 && (module.exports = {
